==================================================
boardgamegeek - A Python API for boardgamegeek.com
==================================================

+-------------+---------------------------------------+
| Stable      | |travis-master| |coveralls-master|    |
+-------------+---------------------------------------+
| Development | |travis-develop| |coveralls-develop|  |
+-------------+---------------------------------------+

Development status:

``boardgamegeek`` is a Python library which makes it easy to access data from BoardGameGeek_ using their official XML
API.

It's an almost completely rewritten fork of libBGG_.


Documentation
=============

Documentation is available at http://lcosmin.github.io/boardgamegeek

.. _BoardGameGeek: http://www.boardgamegeek.com
.. _libBGG: https://github.com/philsstein/libBGG

.. |travis-master| image:: https://travis-ci.org/lcosmin/boardgamegeek.svg?branch=master
    :target: https://travis-ci.org/lcosmin/boardgamegeek

.. |coveralls-master| image:: https://coveralls.io/repos/lcosmin/boardgamegeek/badge.png?branch=master
      :target: https://coveralls.io/r/lcosmin/boardgamegeek?branch=master

.. |travis-develop| image:: https://travis-ci.org/lcosmin/boardgamegeek.svg?branch=develop
      :target: https://travis-ci.org/lcosmin/boardgamegeek

.. |coveralls-develop| image:: https://coveralls.io/repos/lcosmin/boardgamegeek/badge.png?branch=develop
      :target: https://coveralls.io/r/lcosmin/boardgamegeek?branch=develop
